@@ -13,7 +13,7 @@
 use v5.14;
 use warnings;
 
-package Protocol::Sys::Virt::URI v10.3.12;
+package Protocol::Sys::Virt::URI v10.3.13;
 
 use parent qw(Exporter);
 
@@ -79,7 +79,7 @@ Protocol::Sys::Virt::URI - Helper routines for parsing LibVirt URIs
 
 =head1 VERSION
 
-v10.3.12
+v10.3.13
 
 =head1 SYNOPSIS
 
@@ -99,6 +99,7 @@ Helper functions operating on LibVirt hypervisor URLs.
   # { base => 'qemu+ssh://user@password:host/system',
   #   proxy => 'qemu:///system?mode=legacy&socket=/path/socket',
   #   name  => 'qemu:///system',
+  #   type  => 'system',
   #   query => { param => 'value', mode => 'legacy', socket => '/path/socket' },
   #   transport => 'ssh',
   #   hypervisor => 'qemu',
@@ -126,6 +127,11 @@ and C<mode> parameters are passed through).
 This is the URL as it should be passed to the C<name> parameter in
 the protocol's C<REMOTE_PROC_CONNECT_OPEN> message.
 
+=item type
+
+This is the type of session. The value can either be C<system> or
+C<session>.
+
 =item query
 
 Contains a hashref with the (URI-decoded) name/value pairs from
